@@ -167,6 +167,10 @@ OC.L10N.register(
     "Step 2" : "2. samm",
     "Enable for the current domain" : "Luba  kasutamine selle domeeni puhul",
     "Assistance features" : "Abilise funktsionaalsused",
+    "Context Chat integration" : "Kontekstuaalse vestluse lõiming",
+    "About" : "Rakenduse teave",
+    "Acknowledgements" : "Tänuavaldused",
+    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Selles rakenduses sisaldub avatud lähtekoodiga CKEditor, mis on kasutusel kirjade koostamiseks. Autoriõigused: © CKEditori kaasautorid. Litsentseeritud GPLv2 alusel.",
     "Compose new message" : "Koosta uus kiri",
     "Newer message" : "Uuem kiri",
     "Older message" : "Vane kiri",
@@ -177,12 +181,10 @@ OC.L10N.register(
     "Search" : "Otsi",
     "Send" : "Saada",
     "Refresh" : "Värskenda",
-    "About" : "Rakenduse teave",
-    "Acknowledgements" : "Tänuavaldused",
-    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Selles rakenduses sisaldub avatud lähtekoodiga CKEditor, mis on kasutusel kirjade koostamiseks. Autoriõigused: © CKEditori kaasautorid. Litsentseeritud GPLv2 alusel.",
     "Title of the text block" : "Tekstiploki pealkiri",
     "Content of the text block" : "Tekstiploki sisu",
     "Ok" : "Sobib",
+    "Automatically create tentative appointments in calendar" : "Lisa esialgsed kohtumised kalendrisse automaatselt",
     "No certificate" : "Sertifikaati pole",
     "Certificate updated" : "Sertifikaat on uuendatud",
     "Could not update certificate" : "Sertifikaadi uuendamine ei õnnestunud",
@@ -373,6 +375,7 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger folders." : "Indekseerin sinu kirju. Kui kaustad on väga suured, siis võib kuluda natuke aega.",
     "Choose target folder" : "Vali sihtkaust",
     "No more submailboxes in here" : "Siin poel rohkem alampostkaste",
+    "Messages that you marked as favorite will be shown at the top of folders. You can disable this behavior in the app settings" : "Lemmikuks märgitud kirjad järjestuvad kaustas esimestena. Selle valiku saad seadistustest välja lülitada.",
     "Favorites" : "Lemmikud",
     "Favorites info" : "Lemmikute teave",
     "Load more favorites" : "Laadi veel lemmikuid",
