@@ -23,8 +23,10 @@ OC.L10N.register(
     "Archived messages are moved in:" : "I messaggi archiviati sono spostati in:",
     "Junk messages are saved in:" : "I messaggi indesiderati sono salvati in:",
     "Connecting" : "Connessione in corso",
-    "Reconnect Google account" : "Ricollega l'account di Google",
+    "Reconnect Google account" : "Ricollega l'account Google",
     "Sign in with Google" : "Accedi con Google",
+    "Reconnect Microsoft account" : "Ricollega l'account Microsoft",
+    "Sign in with Microsoft" : "Accedi con Microsoft",
     "Save" : "Salva",
     "Connect" : "Connetti",
     "Checking mail host connectivity" : "Verifica della connettività dell'host di posta",
@@ -70,6 +72,7 @@ OC.L10N.register(
     "Autoresponder" : "Risponditore automatico",
     "Calendar settings" : "Impostazioni Calendario",
     "Filters" : "Filtri",
+    "Quick actions" : "Azioni rapide",
     "Mail server" : "Server di posta",
     "Update alias" : "Aggiorna alias",
     "Rename alias" : "Rinomina alias",
@@ -98,6 +101,8 @@ OC.L10N.register(
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Gestisci certificati",
     "Mailvelope" : "Mailvelope",
+    "About" : "Informazioni",
+    "Acknowledgements" : "Ringraziamenti",
     "Compose new message" : "Componi nuovo messaggio",
     "Newer message" : "Messaggio più recente",
     "Older message" : "Messaggio più datato",
@@ -108,7 +113,6 @@ OC.L10N.register(
     "Search" : "Cerca",
     "Send" : "Invia",
     "Refresh" : "Aggiorna",
-    "About" : "Informazioni",
     "Ok" : "Ok",
     "No certificate" : "Nessun certificato",
     "Certificate updated" : "Certificato aggiornato",
@@ -126,11 +130,16 @@ OC.L10N.register(
     "From" : "Da",
     "Select account" : "Seleziona account",
     "To" : "A",
+    "Cc/Bcc" : "Cc/Ccn",
     "Cc" : "Cc",
     "Bcc" : "Ccn",
     "Subject" : "Oggetto",
+    "Subject …" : "Oggetto...",
     "This message came from a noreply address so your reply will probably not be read." : "Nota che il messaggio è arrivato da un indirizzo noreply, perciò la tua risposta non sarà probabilmente letta.",
     "The following recipients do not have a PGP key: {recipients}." : "I seguenti destinatari non hanno una chiave PGP: {recipients}.",
+    "Write message …" : "Scrivi messaggio...",
+    "Saving draft …" : "Salvataggio bozza…",
+    "Error saving draft" : "Errore durante il salvataggio della bozza",
     "Draft saved" : "Bozza salvata",
     "Save draft" : "Salva bozza",
     "Discard & close draft" : "Scarta e chiudi bozza",
@@ -146,7 +155,7 @@ OC.L10N.register(
     "Send now" : "Spedisci ora",
     "Tomorrow morning" : "Domattina",
     "Tomorrow afternoon" : "Domani pomeriggio",
-    "Monday morning" : "Lunedi mattina",
+    "Monday morning" : "Lunedì mattina",
     "Custom date and time" : "Data e ora personalizzate",
     "Enter a date" : "Digita una data",
     "Choose" : "Scegli",
@@ -164,6 +173,7 @@ OC.L10N.register(
     "No messages" : "Nessun messaggio",
     "Blind copy recipients only" : "Solo destinatari in copia nascosta",
     "No subject" : "Nessun oggetto",
+    "{markup-start}Draft:{markup-end} {subject}" : "{markup-start}Bozza:{markup-end} {subject}",
     "Later today – {timeLocale}" : "Oggi – {timeLocale}",
     "Set reminder for later today" : "Imposta promemoria per più tardi oggi",
     "Tomorrow – {timeLocale}" : "Domani – {timeLocale}",
@@ -185,6 +195,7 @@ OC.L10N.register(
     "Mark as spam" : "Marca come posta indesiderata",
     "Edit tags" : "Modifica etichette",
     "Move thread" : "Sposta conversazione",
+    "Move Message" : "Sposta messaggio",
     "Archive thread" : "Archivia la discussione",
     "Archive message" : "Messaggio di archivio",
     "Delete thread" : "Elimina conversazione",
@@ -194,6 +205,7 @@ OC.L10N.register(
     "Edit as new message" : "Modifica come nuovo messaggio",
     "Create task" : "Crea attività",
     "Download message" : "Scarica messaggio",
+    "Back to all actions" : "Torna a tutte le azioni",
     "Load more" : "Carica altro",
     "_Mark {number} read_::_Mark {number} read_" : ["Marca {number} come letto","Marca {number} come letti","Marca {number} come letti"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Marca {number} come non letto","Marca {number} come non letti","Marca {number} come non letti"],
@@ -240,7 +252,8 @@ OC.L10N.register(
     "Itinerary for {type} is not supported yet" : "L'itinerario per {type} non è ancora supportato",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Non ti è consentito spostare questo messaggio nella cartella degli archivi e/o eliminare questo messaggio dalla cartella corrente.",
     "Last hour" : "Ultima ora",
-    "Today" : "Ogg",
+    "Today" : "Oggi",
+    "Yesterday" : "Ieri",
     "Last week" : "Ultima settimana",
     "Last month" : "Ultimo mese",
     "Choose target folder" : "Scegli la cartella di destinazione",
@@ -257,6 +270,7 @@ OC.L10N.register(
     "Move message" : "Sposta messaggio",
     "Translate" : "Traduci",
     "View source" : "Visualizza sorgente",
+    "Print message" : "Stampa messaggio",
     "Download thread data for debugging" : "Scarica i dati del conversazione per il debug",
     "Message body" : "Corpo del messaggio",
     "Unnamed" : "Senza nome",
@@ -319,6 +333,7 @@ OC.L10N.register(
     "attachment" : "allegato",
     "attached" : "allegato",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Stai tentando di inviare a troppi destinatari in A e/o CC. Considera l'idea di utilizzare CCN per nascondere gli indirizzi dei destinatari.",
+    "Your message has no subject. Do you want to send it anyway?" : "Il tuo messaggio non ha oggetto. Vuoi inviarlo comunque?",
     "You mentioned an attachment. Did you forget to add it?" : "Hai menzionato un allegato. Hai dimenticato di aggiungerlo?",
     "Message discarded" : "Messaggio scartato",
     "Could not discard message" : "Impossibile eliminare il messaggio",
@@ -378,6 +393,8 @@ OC.L10N.register(
     "Task created" : "Attività creata",
     "Could not create task" : "Impossibile creare l'attività",
     "Could not load your message thread" : "Impossibile caricare la tua discussione",
+    "Print" : "Stampa",
+    "Could not print message" : "Impossibile stampare il messaggio",
     "Not found" : "Non trovato",
     "Encrypted & verified " : "Cifrato e verificato",
     "Signature verified" : "Firma verificata",
@@ -454,7 +471,7 @@ OC.L10N.register(
     "Error deleting anti spam reporting email" : "Errore durante l'eliminazione dell'email di segnalazione anti-spam",
     "Anti Spam" : "Anti-spam",
     "Add the email address of your anti spam report service here." : "Aggiungi qui l'indirizzo email del tuo servizio di segnalazione anti-spam.",
-    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Quando si utilizza questa impostazione, viene inviata un'e-mail di rapporto al server di rapporto SPAM quando un utente fa clic su \"Segna come posta indesiderata\".",
+    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Quando si utilizza questa impostazione, viene inviata un'email di rapporto al server di rapporto SPAM quando un utente fa clic su \"Segna come posta indesiderata\".",
     "The original message will be attached as a \"message/rfc822\" attachment." : "Il messaggio originale verrà allegato come tipo \"message/rfc822\".",
     "\"Mark as Spam\" Email Address" : "\"Segna come spam\" l'indirizzo e-mail",
     "\"Mark Not Junk\" Email Address" : "\"Segna come posta indesiderata\" l'indirizzo e-mail",
@@ -495,7 +512,7 @@ OC.L10N.register(
     "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Un attributo multi valore per il approvvigionamento di e-mail alias. Per ogni valore viene creato un alias. Gli alias esistenti in Nextcloud che non si trovano nella directory LDAP vengono eliminati.",
     "Save Config" : "Salva configurazione",
     "Unprovision & Delete Config" : "Annullare il approvvigionamento ed eliminare la configurazione",
-    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% e %EMAIL% verranno sostituiti con l'UID e l'e-mail dell'utente",
+    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% e %EMAIL% verranno sostituiti con l'UID e l'email dell'utente",
     "With the settings above, the app will create account settings in the following way:" : "Con le impostazioni precedenti, l'applicazione creerà le impostazioni dell'account nel modo seguente:",
     "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Il certificato PKCS #12 fornito deve contenere almeno un certificato ed esattamente una chiave privata.",
     "Failed to import the certificate. Please check the password." : "Impossibile importare il certificato. Controlla la password.",
