@@ -81,6 +81,7 @@ OC.L10N.register(
     "Days after which messages in Trash will automatically be deleted:" : "다음 일자가 지나면 휴지통의 메시지가 자동으로 삭제됩니다:",
     "Autoresponder" : "자동 응답",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "수신 메시지에 대한 자동 응답입니다. 메시지를 수신한 경우, 이 자동 응답이 최대 4일에 한 번 해당 발신자에게 발송됩니다.",
+    "Calendar settings" : "달력 설정",
     "Filters" : "필터",
     "Mail server" : "메일 서버",
     "Update alias" : "별칭 갱신",
@@ -112,6 +113,7 @@ OC.L10N.register(
     "Security" : "보안",
     "S/MIME" : "S/MIME",
     "Mailvelope" : "Mailvelope",
+    "About" : "정보",
     "Compose new message" : "새 메시지 작성",
     "Newer message" : "새로운 메시지",
     "Older message" : "오래된 메시지",
@@ -332,6 +334,7 @@ OC.L10N.register(
     "Collapse folders" : "폴더 접기",
     "_{total} message_::_{total} messages_" : ["{total} 개의 메시지"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} 개 중 {unread} 개 읽지 않음"],
+    "Loading …" : "로딩 중 …",
     "All messages in mailbox will be deleted." : "편지함에 있는 모든 메시지가 삭제됩니다",
     "Clear mailbox {name}" : "편지함 {name} 비우기",
     "Delete folder" : "폴더 삭제",
@@ -591,6 +594,7 @@ OC.L10N.register(
     "Failed to delete text block" : "텍스트 블록을 삭제하지 못했습니다",
     "Text block shared with {sharee}" : "{sharee}와(과) 텍스트 블록 공유함",
     "Failed to share text block with {sharee}" : "텍스트 블록을 {sharee}와(과) 공유하지 못했습니다",
+    "Group" : "구룹",
     "Failed to save text block" : "텍스트 블록을 저장하지 못했습니다",
     "Shared" : "공유됨",
     "Edit text block" : "텍스트 블록 수정",
