@@ -67,6 +67,7 @@ OC.L10N.register(
     "Preferred writing mode for new messages and replies." : "Pageidaujama rašymo veiksena naujuose laiškuose ir atsakant į laiškus.",
     "Default folders" : "Numatytieji aplankai",
     "Autoresponder" : "Atsakiklis",
+    "Calendar settings" : "Kalendoriaus nustatymai",
     "Filters" : "Filtrai",
     "Mail server" : "Pašto serveris",
     "Go back" : "Grįžti",
@@ -114,6 +115,7 @@ OC.L10N.register(
     "From" : "Nuo",
     "Select account" : "Pasirinkti paskyrą",
     "To" : "Kam",
+    "Contact or email address …" : "Adresatas arba el. pašto adresas …",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Tema",
@@ -201,8 +203,10 @@ OC.L10N.register(
     "Add internal address" : "Pridėti vidinį adresą",
     "Last hour" : "Paskutinė valanda",
     "Today" : "Šiandien",
+    "Yesterday" : "Vakar",
     "Last week" : "Praeitą savaitę",
     "Last month" : "Praeitą mėnesį",
+    "Could not open folder" : "Nepavyko atverti aplanko",
     "Choose target folder" : "Pasirinkite paskirties aplanką",
     "Favorites" : "Mėgstami",
     "Important info" : "Svarbi informacija",
@@ -250,8 +254,10 @@ OC.L10N.register(
     "Collapse folders" : "Suskleisti aplankus",
     "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neskaitytas iš {total}","{unread} neskaityti iš {total}","{unread} neskaitytų iš {total}","{unread} neskaitytas iš {total}"],
+    "Loading …" : "Įkeliama …",
     "All messages in mailbox will be deleted." : "Visi pašto dėžutėje esantys laiškai bus ištrinti.",
     "Clear mailbox {name}" : "Išvalyti pašto dėžutę {name}",
+    "Clear folder" : "Išvalyti aplanką",
     "The folder and all messages in it will be deleted." : "Aplankas ir visi jame esantys laiškai bus ištrinti.",
     "Delete folder" : "Ištrinti aplanką",
     "Delete folder {name}" : "Ištrinti aplanką {name}",
@@ -261,9 +267,11 @@ OC.L10N.register(
     "Rename" : "Pervadinti",
     "Move folder" : "Perkelti aplanką",
     "Clear cache" : "Išvalyti podėlį",
+    "Clear locally cached data, in case there are issues with synchronization." : "Išvalyti vietiniu mastu podėlyje saugomus duomenis tam atvejui, jei yra su sinchronizavimu susijusių klaidų.",
     "Subscribed" : "Prenumeruotas",
     "Sync in background" : "Sinchronizuoti fone",
     "Delete all messages" : "Ištrinti visas žinutes",
+    "Translate this message to {language}" : "Versti šį laišką į {language} kalbą",
     "New message" : "Naujas laiškas",
     "Edit message" : "Taisyti laišką",
     "Draft" : "Juodraštis",
@@ -292,10 +300,12 @@ OC.L10N.register(
     "Contacts with this address" : "Adresatai turintys šį adresą",
     "New Contact" : "Naujas adresatas",
     "Copy to clipboard" : "Kopijuoti į iškarpinę",
+    "Contact name …" : "Adresato vardas …",
     "Add" : "Pridėti",
     "Show less" : "Rodyti mažiau",
     "Show more" : "Rodyti daugiau",
     "Clear" : "Išvalyti",
+    "Search in folder" : "Ieškoti aplanke",
     "Close" : "Užverti",
     "Date" : "Data",
     "Tags" : "Žymos",
@@ -323,6 +333,17 @@ OC.L10N.register(
     "Unsubscribe via link" : "Atsisakyti prenumeratos per nuorodą",
     "Unsubscribe via email" : "Atsisakyti prenumeratos per el. paštą",
     "Newest message" : "Naujausia žinutė",
+    "This summary is AI generated and may contain mistakes." : "Šią santrauką sugeneravo DI ir joje gali būti klaidų.",
+    "Please select languages to translate to and from" : "Pasirinkite kalbas, iš kurių ir į kurias versti",
+    "The message could not be translated" : "Nepavyko išversti laiško",
+    "Translation copied to clipboard" : "Vertimas nukopijuotas į iškarpinę",
+    "Translation could not be copied" : "Nepavyko nukopijuoti vertimo",
+    "Translate message" : "Versti laišką",
+    "Source language to translate from" : "Pradinė kalba, iš kurios versti",
+    "Translate from" : "Versti iš",
+    "Target language to translate into" : "Paskirties kalbą, į kurią versti",
+    "Translate to" : "Versti į",
+    "Translating" : "Verčiama",
     "Could not remove trusted sender {sender}" : "Nepavyko pašalinti patikimo siuntėjo {sender}",
     "No senders are trusted at the moment." : "Šiuo metu nėra patikimų siuntėjų.",
     "Untitled event" : "Įvykis be pavadinimo",
@@ -335,9 +356,11 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iš {depStation} į {arrStation}",
     "Train from {depStation} to {arrStation}" : "Traukinys iš {depStation} į {arrStation}",
     "Train" : "Traukinys",
+    "Move into folder" : "Perkelti į aplanką",
     "Stop" : "Stabdyti",
     "Delete action" : "Ištrinti veiksmą",
     "Deleted" : "Ištrinta",
+    "Sender" : "Siuntėjas",
     "Recipient" : "Gavėjas",
     "Delete filter" : "Ištrinti filtrą",
     "Delete mail filter {filterName}?" : "Ištrinti pašto filtrą {filterName}?",
@@ -349,11 +372,13 @@ OC.L10N.register(
     "Help" : "Pagalba",
     "matches" : "atitinka",
     "Actions" : "Veiksmai",
+    "Add action" : "Pridėti veiksmą",
     "Priority" : "Pirmenybė",
     "Enable filter" : "Įjungti filtrą",
     "Tag" : "Žymė",
     "delete" : "ištrinti",
     "Edit" : "Taisyti",
+    "Add another action" : "Pridėti kitą veiksmą",
     "Error saving config" : "Klaida įrašant konfigūraciją",
     "Mail app" : "Pašto programėlė",
     "The mail app allows users to read mails on their IMAP accounts." : "Pašto programėlė leidžia naudotojams skaityti laiškus savo IMAP paskyrose.",
@@ -362,6 +387,7 @@ OC.L10N.register(
     "Allow additional mail accounts" : "Leisti papildomas pašto paskyras",
     "Gmail integration" : "„Gmail“ integracija",
     "Microsoft integration" : "„Microsoft“ integracija",
+    "For more details, please click here to open our documentation." : "Išsamesnei informacijai, spustelėkite čia, kad būtų atverta dokumentacija.",
     "The original message will be attached as a \"message/rfc822\" attachment." : "Pradinis laiškas bus pridėtas kaip priedas „message/rfc822“.",
     "Reset" : "Atstatyti",
     "Google integration configured" : "„Google“ integracija sukonfigūruota",
@@ -384,6 +410,8 @@ OC.L10N.register(
     "Host" : "Serveris",
     "Port" : "Prievadas",
     "SMTP" : "SMTP",
+    "Master password" : "Pagrindinis slaptažodis",
+    "Use master password" : "Naudoti pagrindinį slaptažodį",
     "Save Config" : "Įrašyti konfigūraciją",
     "With the settings above, the app will create account settings in the following way:" : "Naudodama aukščiau esančius nustatymus, programėlė sukurs paskyrai nustatymus štai tokiu būdu: ",
     "Certificate imported successfully" : "Liudijimas sėkmingai importuotas",
@@ -400,6 +428,8 @@ OC.L10N.register(
     "Certificate" : "Liudijimas",
     "Submit" : "Pateikti",
     "Shared" : "Bendrinama",
+    "Edit {title}" : "Taisyti {title}",
+    "Delete {title}" : "Ištrinti {title}",
     "Shares" : "Viešiniai",
     "Account connected" : "Paskyra prijungta",
     "You can close this window" : "Galite užverti šį langą",
