@@ -17,12 +17,12 @@ OC.L10N.register(
     "Appearance" : "Tashqi ko'rinish",
     "List" : "Ro`yxat",
     "Security" : "Xavfsizlik",
+    "About" : "About",
     "Archive" : "Arxiv",
     "Delete" : "O'chirish",
     "Search" : "Qidirish",
     "Send" : "Send",
     "Refresh" : "Refresh",
-    "About" : "About",
     "Ok" : "Yaxshi",
     "From" : "Dan",
     "To" : "Gacha",
@@ -45,6 +45,7 @@ OC.L10N.register(
     "Decline" : "Rad etish",
     "More options" : "Boshqa variantlar",
     "Remove" : "O'chirish",
+    "Last hour" : "So'nggi soat",
     "Today" : "Bugun",
     "Yesterday" : "Kecha",
     "Last week" : "O`tgan yil",
@@ -81,6 +82,7 @@ OC.L10N.register(
     "Submit" : "Submit",
     "Group" : "Guruh",
     "Shared" : "Ulashilgan",
+    "Shares" : "Ulashishlar",
     "Account connected" : "Akkaunt ulangan",
     "All" : "All",
     "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
