@@ -3,23 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @author Tahaa Karim <tahaalibra@gmail.com>
- * @author Richard Steinmetz <richard@steinmetz.cloud>
- *
- * Mail
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 
 namespace OCA\Mail\Controller;
@@ -30,9 +15,11 @@ use OCA\Mail\Service\AliasesService;
 use OCP\AppFramework\Controller;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\Attribute\OpenAPI;
 use OCP\AppFramework\Http\JSONResponse;
 use OCP\IRequest;
 
+#[OpenAPI(scope: OpenAPI::SCOPE_IGNORE)]
 class AliasesController extends Controller {
 	private AliasesService $aliasService;
 	private string $currentUserId;
@@ -73,10 +60,10 @@ class AliasesController extends Controller {
 	 * @NoAdminRequired
 	 */
 	#[TrapError]
-	public function update(int    $id,
+	public function update(int $id,
 		string $alias,
 		string $aliasName,
-		?int   $smimeCertificateId = null): JSONResponse {
+		?int $smimeCertificateId = null): JSONResponse {
 		return new JSONResponse(
 			$this->aliasService->update(
 				$this->currentUserId,
