@@ -3,24 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @copyright 2019 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @author 2019 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Mail\Db;
@@ -46,7 +30,7 @@ class MailboxMapper extends QBMapper {
 	private $timeFactory;
 
 	public function __construct(IDBConnection $db,
-								ITimeFactory $timeFactory) {
+		ITimeFactory $timeFactory) {
 		parent::__construct($db, 'mail_mailboxes');
 		$this->timeFactory = $timeFactory;
 	}
@@ -92,20 +76,19 @@ class MailboxMapper extends QBMapper {
 			->from($this->getTableName())
 			->where(
 				$qb->expr()->eq('account_id', $qb->createNamedParameter($account->getId())),
-				$qb->expr()->eq('name', $qb->createNamedParameter($name))
+				$qb->expr()->eq('name_hash', $qb->createNamedParameter(md5($name)))
 			);
 
 		try {
 			return $this->findEntity($select);
 		} catch (MultipleObjectsReturnedException $e) {
 			// Not possible due to DB constraints
-			throw new ServiceException("The impossible has happened", 42, $e);
+			throw new ServiceException('The impossible has happened', 42, $e);
 		}
 	}
 
 	/**
 	 * @param int $id
-	 * @param string $uid
 	 *
 	 * @return Mailbox
 	 *
@@ -125,7 +108,7 @@ class MailboxMapper extends QBMapper {
 			return $this->findEntity($select);
 		} catch (MultipleObjectsReturnedException $e) {
 			// Not possible due to DB constraints
-			throw new ServiceException("The impossible has happened", 42, $e);
+			throw new ServiceException('The impossible has happened', 42, $e);
 		}
 	}
 
@@ -170,7 +153,7 @@ class MailboxMapper extends QBMapper {
 			return $this->findEntity($select);
 		} catch (MultipleObjectsReturnedException $e) {
 			// Not possible due to DB constraints
-			throw new ServiceException("The impossible has happened", 42, $e);
+			throw new ServiceException('The impossible has happened', 42, $e);
 		}
 	}
 
@@ -230,10 +213,6 @@ class MailboxMapper extends QBMapper {
 	}
 
 	/**
-	 * @param Mailbox $mailbox
-	 * @param IQueryBuilder $query
-	 * @param int|null $value
-	 *
 	 * @return string|IQueryFunction
 	 */
 	private function eqOrNull(IQueryBuilder $query, string $column, ?int $value, int $type) {
@@ -268,9 +247,7 @@ class MailboxMapper extends QBMapper {
 			->leftJoin('m', 'mail_accounts', 'a', $qb1->expr()->eq('m.account_id', 'a.id'))
 			->where($qb1->expr()->isNull('a.id'));
 		$result = $idsQuery->executeQuery();
-		$ids = array_map(static function (array $row) {
-			return (int)$row['id'];
-		}, $result->fetchAll());
+		$ids = array_map(static fn (array $row) => (int)$row['id'], $result->fetchAll());
 		$result->closeCursor();
 
 		$qb2 = $this->db->getQueryBuilder();
@@ -290,16 +267,14 @@ class MailboxMapper extends QBMapper {
 	public function findFlaggedImportantUids(int $mailboxId) : array {
 		$qb = $this->db->getQueryBuilder();
 		$query = $qb->select('uid')
-				->from('mail_messages')
-				->where(
-					$qb->expr()->eq('mailbox_id', $qb->createNamedParameter($mailboxId)),
-					$qb->expr()->eq('flag_important', $qb->createNamedParameter(true, IQueryBuilder::PARAM_BOOL))
-				);
+			->from('mail_messages')
+			->where(
+				$qb->expr()->eq('mailbox_id', $qb->createNamedParameter($mailboxId)),
+				$qb->expr()->eq('flag_important', $qb->createNamedParameter(true, IQueryBuilder::PARAM_BOOL))
+			);
 
 		$cursor = $query->executeQuery();
-		$uids = array_map(static function (array $row) {
-			return (int)$row['uid'];
-		}, $cursor->fetchAll());
+		$uids = array_map(static fn (array $row) => (int)$row['uid'], $cursor->fetchAll());
 		$cursor->closeCursor();
 
 		return $uids;
