@@ -23,6 +23,7 @@ class Version0190Date20191118160843 extends SimpleMigrationStep {
 	 *
 	 * @return ISchemaWrapper
 	 */
+	#[\Override]
 	public function changeSchema(IOutput $output, Closure $schemaClosure, array $options) {
 		/** @var ISchemaWrapper $schema */
 		$schema = $schemaClosure();
@@ -32,7 +33,7 @@ class Version0190Date20191118160843 extends SimpleMigrationStep {
 			'notnull' => false,
 			'default' => false,
 		]);
-		$accountsTable->changeColumn('inbound_password', [
+		$accountsTable->modifyColumn('inbound_password', [
 			'notnull' => false,
 			'default' => null,
 		]);
